@@ -10,6 +10,7 @@ sub setup {
         test_add
         test_clear
         test_body
+        test_callback
     )]);
 
     $self->start_mode('test_json');
@@ -48,4 +49,16 @@ sub test_body {
     );
 }
 
+sub test_callback {
+    my $self = shift;
+    return $self->json_callback(
+       'my_callback',
+      {
+        foo => 'blah',
+        baz => 'stuff',
+        bar => 'more_stuff',
+      }
+    );
+}
+
 1;
